{
 copyright   : daniel lorch 1999 <daniel@lorch.cc> (deutsch, english understood)
               http://raylight.hypermart.net
 name        : raylight Autostart (TRaylightAutostart)
 language    : everything greater than delphi 2.0 (only on 2.0 tested)
 description : allows you to start your applications automatically
               on windows-startup (autostart) with a matter of a single mouse click.
               just change the property 'autostart' (truefalse) and your program
               will start up every time windows starts up. TRaylightAutostart will
               automatically write required settings into the registry (or remove
               them if needed).
 legal       : this component ist credit-ware. credit-ware inherits directly
               from public domain software what means that you are allowed
               to use it without any restrictions. the only difference is
               that you have to give proper credits (in readme or in the program
               itself. suggested way is to use TRaylightUrlLabel (also available
               on my homepage) which allows you to have 'hyperlinks' in you programs
               and link to my homepage. i'd also appreciate if you could send me
               a little note where to get your program so i can have a
               look at it.
               I take no responsibility for any damage or consequences directly or
               indirectly, intentionally or unintentionally, which may arise from
               using this program. YOU USE IT AT YOUR OWN RISK!
 history     : (dd/mm/yyyy) format
               1.00 (08.03.1999) daniel lorch <daniel@lorch.cc>:
                -initial release

 modifying   : if you've made any improvements, first add your name to the
               'history' (above), make a brief description of all the changes
               you've made, increase version number by 0.01 and add the current date.
               then send me a copy of it (if you want). you can also check my
               homepage for recent improvements.
 usage       : raylight Autostart is an non-windowed (= invisible) component.
               new properties are:
               -autostart (boolean): start program every time windows is started up
               -appName (string)   : this must be an unique name identyfying your
                                     application. raylight autostart requires this
                                     string to save settings into the registry. usually
                                     the name of your application is sufficient.

               sample code:

                procedure TForm1.FormCreate(Sender: TObject);
                begin
                 checkbox1.caption := 'Start this application on windows startup.';
                 checkbox1.checked := RaylightAutostart1.autostart;
                end;

                procedure TForm1.CheckBox1Click(Sender: TObject);
                begin
                 RaylightAutostart1.autostart := checkbox1.checked;
                end;
}

unit raylightAutostart;

interface

uses
  Windows, Messages, SysUtils, Controls, Forms, Graphics, Dialogs,
  StdCtrls, Classes, registry, shellapi, Clipbrd, Menus;

type
  TRaylightAutostart = class(TComponent)
  private
    FAppName   : string;
    FAutoStart : boolean;

    function checkAutostart: boolean;
    procedure writeAutostart(value: boolean);
  protected
    { Protected-Deklarationen }
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  published
    property appName   : string read FAppName write FAppName;
    property autostart : boolean read checkAutostart write writeAutostart;
  end;

procedure Register;

implementation

{$R raylightAutostart.res}

function TRaylightAutostart.checkAutostart: boolean;
begin
 if FAppName <> '' then
 with TRegistry.Create do
 try
  RootKey := HKEY_LOCAL_MACHINE;

  OpenKey ('\SOFTWARE\Microsoft\Windows\CurrentVersion\Run', true);
  if ReadString(FAppName) = ''
   then FAutoStart := false
   else FAutoStart := true;

  CloseKey;
 finally
  Free;
 end;

 result := FAutoStart;
end;

procedure TRaylightAutostart.writeAutostart(value: boolean);
const
 firsttime : boolean = true;
begin
 {
  when delphi creates the component it first calls 'writeAutostart' instead
  of 'readAutostart'. but as we first want to check the registry rather
  than using values that were in the component's constructor and overwrite
  previous settings saved in the registry, i've programmed this workaround.
 }
 if firsttime then
 begin
  value := checkAutostart;
  firsttime := false;
 end;

 if FAppName <> '' then
 with TRegistry.Create do
 try
  RootKey := HKEY_LOCAL_MACHINE;
  OpenKey ('\SOFTWARE\Microsoft\Windows\CurrentVersion\Run', true);

  if value then
  begin
   WriteString(FAppName, Application.Exename);
   FAutoStart := true;
  end else begin
   DeleteValue(FAppName);
   FAutoStart := false;
  end;

  CloseKey;
 finally
  Free;
 end;
end;

constructor TRaylightAutostart.create(AOwner: TComponent);
begin
 inherited Create(AOwner);

 if not (csDesigning in ComponentState) then
  FAppName := Application.Title;
end;

destructor TRaylightAutostart.destroy;
begin
 inherited destroy;

 //nothing to do
end;

procedure Register;
begin
  RegisterComponents('Raylight Software', [TRaylightAutostart]);
end;

end.
